import unittest
from spongebox.mediabox import Tailor

frgs = []
frgs.append(("000000", "010438"))
# frgs.append(("000106", "000136"))
# Tailor("F:\\download\\20\\vedio.mp4").launch(frgs)
# Tailor("F:\\download\\20\\FCDC-123.mp4",output_dir="F:\\download\\20").launch(frgs)
Tailor("C:\\Users\\LuoJi\\Desktop\\HJMO-457.mp4",output_dir="C:\\Users\\LuoJi\\Desktop").launch(frgs)